@@ -1,13 +1,16 @@
 # noinspection PyUnresolvedReferences
 from .. import *
 from .. import dispatch as dispatch_original
+from ..shape import dispatch_unwrap_dimensions
 from ..types import Number, NPNumeric
 
+dispatch_unwrapped = dispatch_unwrap_dimensions(dispatch_original)
+
 
 # All methods here should have precedence, because NumPy forms the base of everything.
 def dispatch(*args, **kw_args):
     kw_args["precedence"] = 1
-    return dispatch_original(*args, **kw_args)
+    return dispatch_unwrapped(*args, **kw_args)
 
 
 Numeric = {Number, NPNumeric}
