@@ -13,6 +13,8 @@ from .shaping import *
 from .linear_algebra import *
 from .random import *
 
+import tensorflow as tf
+
 # noinspection PyUnresolvedReferences
 from ..types import _tf_retrievables
 
@@ -20,5 +22,8 @@ from ..types import _tf_retrievables
 for retrievable in _tf_retrievables:
     retrievable.retrieve()
 
+# Set TF device manager.
+B.Device._tf_manager = tf.device
+
 # Alias to actual module.
 sys.modules[__name__] = B
