@@ -1,7 +1,11 @@
 # noinspection PyUnresolvedReferences
 from .. import *
+from .. import dispatch as dispatch_original
+from ..shape import dispatch_unwrap_dimensions
 from ..types import Number, TorchNumeric
 
+dispatch = dispatch_unwrap_dimensions(dispatch_original)
+
 Numeric = {Number, TorchNumeric}
 
 from .generic import *
@@ -10,7 +14,6 @@ from .linear_algebra import *
 from .random import *
 
 # noinspection PyUnresolvedReferences
-import torch
 from ..types import _torch_retrievables
 
 # Retrieve types.
